| PyPI Release | Test Status | Code Coverage |
| ------------ | ----------- | ------------- |
| [![PyPI version](https://badge.fury.io/py/rms-psfmodel.svg)](https://badge.fury.io/py/rms-psfmodel) | [![Build status](https://img.shields.io/github/actions/workflow/status/SETI/rms-psfmodel/run-tests.yml?branch=master)](https://github.com/SETI/rms-psfmodel/actions) | [![Code coverage](https://img.shields.io/codecov/c/github/SETI/rms-psfmodel/main?logo=codecov)](https://codecov.io/gh/SETI/rms-psfmodel) |

# rms-psfmodel

Supported versions: Python >= 3.8
